==> haskell-wide-word-0.1.8.1-25.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wide-word.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wide-word
version:              0.1.8.1
visibility:           public
id:                   wide-word-0.1.8.1-HknJV6gVayJJ5pZG8ouIaG
key:                  wide-word-0.1.8.1-HknJV6gVayJJ5pZG8ouIaG
license:              BSD-2-Clause
copyright:
    Copyright (c) 2017 Erik de Castro Lopo <erikd@mega-nerd.com>

maintainer:           erikd@mega-nerd.com
author:               Erik de Castro Lopo
stability:            provisional
homepage:             https://github.com/erikd/wide-word
synopsis:
    Data types for large but fixed width signed and unsigned integers

description:
    A library to provide data types for large (ie > 64 bits) but fixed width signed
    and unsigned integers with the usual typeclass instances to allow them to be used
    interchangeably with `Word64`.

    The types and operations are coded to be as fast as possible using strictness
    annotations, `INLINEABLE` pragmas and unboxed values and operations where
    appropriate.

category:             Data
abi:                  56a7b4f0290c0b34e3d6db0b43a4ea49
exposed:              True
exposed-modules:
    Data.WideWord Data.WideWord.Int128 Data.WideWord.Word128
    Data.WideWord.Word256 Data.WideWord.Word64

hidden-modules:       Data.WideWord.Compat
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wide-word-0.1.8.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wide-word-0.1.8.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wide-word-0.1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wide-word
hs-libraries:         HSwide-word-0.1.8.1-HknJV6gVayJJ5pZG8ouIaG
depends:
    base-4.18.2.1 binary-0.8.9.1 deepseq-1.4.8.1
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ

haddock-interfaces:   /usr/share/doc/haskell-wide-word/html/wide-word.haddock
haddock-html:         /usr/share/doc/haskell-wide-word/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wide-word-0.1.8.1-26-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wide-word.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wide-word
version:              0.1.8.1
visibility:           public
id:                   wide-word-0.1.8.1-6qCDci4eB9c2kwAkNdKdix
key:                  wide-word-0.1.8.1-6qCDci4eB9c2kwAkNdKdix
license:              BSD-2-Clause
copyright:
    Copyright (c) 2017 Erik de Castro Lopo <erikd@mega-nerd.com>

maintainer:           erikd@mega-nerd.com
author:               Erik de Castro Lopo
stability:            provisional
homepage:             https://github.com/erikd/wide-word
synopsis:
    Data types for large but fixed width signed and unsigned integers

description:
    A library to provide data types for large (ie > 64 bits) but fixed width signed
    and unsigned integers with the usual typeclass instances to allow them to be used
    interchangeably with `Word64`.

    The types and operations are coded to be as fast as possible using strictness
    annotations, `INLINEABLE` pragmas and unboxed values and operations where
    appropriate.

category:             Data
abi:                  029b33cf89c2340c3493c06340176c7f
exposed:              True
exposed-modules:
    Data.WideWord Data.WideWord.Int128 Data.WideWord.Word128
    Data.WideWord.Word256 Data.WideWord.Word64

hidden-modules:       Data.WideWord.Compat
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wide-word-0.1.8.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wide-word-0.1.8.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wide-word-0.1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wide-word
hs-libraries:         HSwide-word-0.1.8.1-6qCDci4eB9c2kwAkNdKdix
depends:
    base-4.18.2.1 binary-0.8.9.1 deepseq-1.4.8.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi

haddock-interfaces:   /usr/share/doc/haskell-wide-word/html/wide-word.haddock
haddock-html:         /usr/share/doc/haskell-wide-word/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
